=== modified file 'Makefile.am'
--- Makefile.am	2022-06-25 09:19:10 +0000
+++ Makefile.am	2022-08-05 08:09:45 +0000
@@ -19,6 +19,7 @@
 # Date		Author	Version	Description				#
 #									#
 # 30/05/2022	MG	1.0.1	First release.				#
+# 04/08/2022	MG	1.0.2	Add new config file build.		#
 #									#
 #########################################################################
 
@@ -29,7 +30,8 @@
 AM_DISTCHECK_CONFIGURE_FLAGS =
 
 
-SUBDIRS = src/man/1
+SUBDIRS = src/conf/etc
+SUBDIRS += src/man/1
 SUBDIRS += src/prg/bash
 
 

=== modified file 'configure.ac'
--- configure.ac	2022-07-31 14:12:18 +0000
+++ configure.ac	2022-08-05 08:09:45 +0000
@@ -39,6 +39,7 @@
 # Date		Author	Version	Description				#
 #									#
 # 30/05/2022	MG	1.0.1	First release.				#
+# 04/08/2022	MG	1.0.2	Add new config file build.		#
 #									#
 #########################################################################
 
@@ -53,7 +54,7 @@
 	      This script is free to copy or distribute under the terms set out
 	      in the package license. See COPYING for details.])
 
-AC_REVISION([$Revision: 1.0.1 $])
+AC_REVISION([$Revision: 1.0.2 $])
 
 AC_PREREQ([2.69])
 
@@ -71,7 +72,7 @@
 # in source files.
 #
 # Set pkg_version for a default hard-coded version number.
-m4_define(pkg_version, 1.0.2)
+m4_define(pkg_version, 1.0.2+rc1)
 
 AC_INIT([Kernel Utilities], m4_esyscmd([ \
 	git describe --always 1>/dev/null 2>/dev/null \
@@ -283,6 +284,7 @@
 
 # Project Makefiles to create.
 AC_CONFIG_FILES([Makefile
+		src/conf/etc/Makefile
 		src/man/1/Makefile
 		src/prg/bash/Makefile])
 

=== added directory 'src/conf'
=== added directory 'src/conf/etc'
=== added file 'src/conf/etc/Makefile.am'
--- src/conf/etc/Makefile.am	1970-01-01 00:00:00 +0000
+++ src/conf/etc/Makefile.am	2022-08-05 08:09:45 +0000
@@ -0,0 +1,41 @@
+#########################################################################
+#									#
+# Script ID: src/conf/etc/Makefile.am					#
+# Author: Copyright (C) 2022  Mark Grant				#
+#									#
+# Released under the GPLv3 only.					#
+# SPDX-License-Identifier: GPL-3.0-only					#
+#									#
+# Purpose:								#
+# AutoMake script file to install obs-utils configuration files.	#
+#									#
+#########################################################################
+
+#########################################################################
+#									#
+# Changelog								#
+#									#
+# Date		Author	Version	Description				#
+#									#
+# 04/08/2022	MG	1.0.1	Initial release.			#
+#									#
+#########################################################################
+
+
+confdir = $(sysconfdir)
+
+
+obs-utils.conf: Makefile
+	mkdir -p $(@D)
+	rm -f $@ $@.tmp
+	test -f ./$@.in || srcdir=$(srcdir)/; \
+	$(edit) $${srcdir}$(@F).in > $@.tmp
+	mv $@.tmp $@
+obs-utils.conf: $(srcdir)/obs-utils.conf.in
+
+conf_DATA = obs-utils.conf
+
+EXTRA_DIST = $(srcdir)/obs-utils.conf.in
+
+CLEANFILES = *.tmp obs-utils.conf
+

=== added file 'src/conf/etc/obs-utils.conf.in'
--- src/conf/etc/obs-utils.conf.in	1970-01-01 00:00:00 +0000
+++ src/conf/etc/obs-utils.conf.in	2022-08-05 08:09:45 +0000
@@ -0,0 +1,3 @@
+# You can use tilde for the home directory
+base_output_dir=~/SWDev/oscbuilder
+

=== modified file 'src/prg/bash/oscbuilder.sh.in'
--- src/prg/bash/oscbuilder.sh.in	2022-07-31 14:12:18 +0000
+++ src/prg/bash/oscbuilder.sh.in	2022-08-05 08:09:45 +0000
@@ -65,6 +65,9 @@
 #				may not	be a standard format.		#
 #				Move release format processing to the	#
 #				spec file.				#
+# 01/08/2022	MG	1.0.3	Correct built-pkgs path.		#
+# 04/08/2022	MG	1.0.4	Add config file with a base output dir	#
+#				entry.					#
 #									#
 #########################################################################
 
@@ -77,11 +80,13 @@
 ##################
 readonly outputprefix="$(basename $0):"
 
-readonly version=1.0.2				# Script version
+readonly version=1.0.4				# Script version
 readonly packageversion=@pkgversion@		# Package version
 
 arch="x86_64"					# Default architecture
+base_output_dir=""
 cla=""
+readonly conffile=@sysconfdir@/obs-utils.conf
 repo=""
 
 
@@ -156,6 +161,54 @@
 trap trap_exit SIGHUP SIGINT SIGQUIT SIGTERM
 
 
+# Process config file.
+# No parameters.
+# No return value.
+proc_config_file()
+{
+	local old_IFS
+	local read_base_output_dir
+
+	if [[ ! -f $conffile ]]; then
+		output "Config file $conffile does not exist." 1
+		script_exit 77
+	fi
+	if [[ ! -r $conffile ]]; then
+		output "Incorrect permissions for config file $conffile." 1
+		script_exit 77
+	fi
+
+	old_IFS=$IFS
+	IFS="="
+	exec 3<$conffile
+	while read -u3 -ra input; do
+		# Discard comment lines.
+		[[ "${input[0]}" =~ ^[[:blank:]]*# ]] && continue
+		case ${input[0]} in
+		base_output_dir)
+			read_base_output_dir=${input[1]}
+			;;
+		esac
+	done
+	exec 3<&-
+	IFS=$old_IFS
+
+	if [[ "${read_base_output_dir:0:1}" == "~" ]]; then
+		base_output_dir="${HOME}${read_base_output_dir:1}"
+	else
+		base_output_dir="${read_base_output_dir}"
+	fi
+
+	if [[ ! -d $base_output_dir ]]; then
+		output "Config file output dir not a directory." 1
+		script_exit 77
+	fi
+	if [[ ! -r $base_output_dir ]]; then
+		output "Incorrect permissions for base output directory." 1
+		script_exit 77
+	fi
+}
+
 # Process command line arguments with GNU getopt.
 # Parameters -	$1 is the command line.
 # No return value.
@@ -243,15 +296,14 @@
 # Main #
 ########
 
+proc_config_file
+
 proc_CL "$@"
 
 set_dist_default
 
-
-rm -vf ../../$repo/$arch/pkgs/*
-
-osc build -k ~/SWDev/oscbuilder/$repo/$arch/built-pkgs \
-	-p ~/SWDev/oscbuilder/$repo/$arch/tmp-pkg-cache \
+osc build -k "$base_output_dir/$repo/$arch/built-pkgs" \
+	-p "$base_output_dir/$repo/$arch/tmp-pkg-cache" \
 	$repo $arch $cla
 
 # And exit.

